@@ -41,6 +41,8 @@ import javax.swing.KeyStroke;
 import javax.swing.event.MenuEvent;
 import javax.swing.event.MenuListener;
 
+import org.dpolivaev.mnemonicsetter.MnemonicSetter;
+
 /**
  * Provides methods to dynamically combine components and resource bundles.
  *
@@ -151,6 +153,7 @@ class DynamicResource {
                 mb.add(m);
             }
         }
+        MnemonicSetter.INSTANCE.setComponentMnemonics(mb);
         return mb;
     }
 
@@ -184,6 +187,7 @@ class DynamicResource {
          * store the menu in the menus hashtable for possible later use
          */
         menus.put(key, menu);
+        MnemonicSetter.INSTANCE.setComponentMnemonics(menu.getPopupMenu());
         return menu;
     }
 
@@ -212,6 +216,7 @@ class DynamicResource {
                 menu.add(mi);
             }
         }
+        MnemonicSetter.INSTANCE.setComponentMnemonics(menu);
         return menu;
     }
 
